@@ -3,11 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0303';
+our $VERSION = '0.0304';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
-use List::Util qw(any uniq);
+use List::Util qw(any min uniq);
 use Music::Chord::Note;
 use Music::Note;
 use Music::Scales qw(get_scale_notes get_scale_MIDI);
@@ -160,6 +160,9 @@ sub generate {
         intervals => $self->intervals,
     );
 
+    # Try to start the phrase at the beginning of the scale
+    $voice->context($fixed[0]) if $self->tonic;
+
     # Get a passage of quasi-random pitches
     my @chosen = map { $voice->rand } 1 .. $num;
 
@@ -175,8 +178,10 @@ sub generate {
             my @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @intersect;
             print "\tINTERSECT: ",ddc(\@named);
         }
-        # Lead to the next chord
-        $chosen[-1] = $intersect[int rand @intersect] if @intersect;
+        # Anticipate the next chord
+        if (@intersect) {
+            $chosen[-1] = _closest($chosen[-2], \@intersect);
+        }
     }
 
     # Show them what they've won, Bob!
@@ -188,6 +193,20 @@ sub generate {
     return \@chosen;
 }
 
+# Find the closest absolute difference to the key, in the list
+sub _closest {
+    my ($key, $list) = @_;
+    $list = [ grep { $_ != $key } @$list ];
+    my @diff = map { abs($key - $_) } @$list;
+    my $min = min @diff;
+    my @closest;
+    for my $n (0 .. $#diff) {
+        next if $diff[$n] != $min || $list->[$n] == $key;
+        push @closest, $list->[$n];
+    }
+    return $closest[int rand @closest];
+}
+
 1;
 
 __END__
@@ -202,7 +221,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0303
+version 0.0304
 
 =head1 SYNOPSIS
 
